@@ -1,21 +1,21 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2012-2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2012-2021 -- leonerd@leonerd.org.uk
 
-package Tickit::Widget::Box;
+use Object::Pad 0.51;
+
+package Tickit::Widget::Box 0.55;
+class Tickit::Widget::Box
+   extends Tickit::SingleChildWidget;
+
+use Carp;
 
-use strict;
-use warnings;
-use 5.010; # //
-use base qw( Tickit::SingleChildWidget );
 use Tickit::Style;
 use Tickit::RenderBuffer;
 
 use Tickit::Utils qw( bound );
 
-our $VERSION = '0.53';
-
 use constant WIDGET_PEN_FROM_STYLE => 1;
 
 =head1 NAME
@@ -103,40 +103,40 @@ Initial values for alignment options.
 
 =cut
 
-sub new
+ADJUSTPARAMS
 {
-   my $class = shift;
-   my %args = @_;
-   my $self = $class->SUPER::new( @_ );
+   my ( $params ) = @_;
 
    foreach (qw( child_lines_min child_lines_max child_cols_min child_cols_max
                 child_lines                     child_cols )) {
-      if( defined $args{$_} ) { $self->${\"set_$_"}( $args{$_} ) }
+      my $val = delete $params->{$_};
+      $self->${\"set_$_"}( $val ) if defined $val;
    }
 
-   $self->set_align ( $args{align}  // 0.5 );
-   $self->set_valign( $args{valign} // 0.5 );
+   foreach (qw( align valign )) {
+      my $val = delete $params->{$_};
+      $self->${\"set_$_"}( $val // 0.5 );
+   }
 
-   return $self;
+   if( exists $params->{child} ) {
+      croak "The 'child' constructor argument to ${\ref $self} is no longer recognised; use ->add_child instead";
+   }
 }
 
-sub lines
+method lines
 {
-   my $self = shift;
    my $child = $self->child;
    return $child ? bound( $self->child_lines_min, $child->requested_lines, $self->child_lines_max ) : 1;
 }
 
-sub cols
+method cols
 {
-   my $self = shift;
    my $child = $self->child;
    return $child ? bound( $self->child_cols_min, $child->requested_cols, $self->child_cols_max ) : 1;
 }
 
-sub render_to_rb
+method render_to_rb
 {
-   my $self = shift;
    my ( $rb, $rect ) = @_;
 
    $rb->eraserect( $rect );
@@ -202,16 +202,22 @@ the same value. This has the effect of forcing the size of the child widget.
 
 =cut
 
+has $_child_lines_max; method _child_lines_max :lvalue { $_child_lines_max }
+has $_child_lines_min; method _child_lines_min :lvalue { $_child_lines_min }
+has $_child_cols_max;  method _child_cols_max  :lvalue { $_child_cols_max  }
+has $_child_cols_min;  method _child_cols_min  :lvalue { $_child_cols_min  }
+
 # Because I hate copying code 4 times
 foreach my $dir (qw( lines cols )) {
    my %subs;
 
    foreach my $lim (qw( max min )) {
+      my $slotmeth = "_child_${dir}_${lim}";
       my $name = "child_${dir}_${lim}";
 
       $subs{$name} = sub {
          my $self = shift;
-         my $value = $self->{$name};
+         my $value = $self->$slotmeth;
          if( !defined $value ) {
             return undef;
          }
@@ -226,7 +232,7 @@ foreach my $dir (qw( lines cols )) {
 
       $subs{"set_$name"} = sub {
          my $self = shift;
-         ( $self->{$name} ) = @_;
+         ( $self->$slotmeth ) = @_;
          $self->resized;
       };
    }
@@ -247,10 +253,8 @@ foreach my $dir (qw( lines cols )) {
 use Tickit::WidgetRole::Alignable name =>  "align", dir => "h", reshape => 1;
 use Tickit::WidgetRole::Alignable name => "valign", dir => "v", reshape => 1;
 
-sub reshape
+method reshape
 {
-   my $self = shift;
-
    my $window = $self->window or return;
    my $child  = $self->child or return;
 
@@ -268,9 +272,8 @@ sub reshape
    $self->redraw;
 }
 
-sub window_lost
+method window_lost
 {
-   my $self = shift;
    my $child = $self->child or return;
    $child->set_window( undef );
 }
