@@ -3,9 +3,9 @@
 #
 #  (C) Paul Evans, 2013-2021 -- leonerd@leonerd.org.uk
 
-use Object::Pad 0.27;
+use Object::Pad 0.51;
 
-package Tickit::Widget::HSplit 0.32;
+package Tickit::Widget::HSplit 0.33;
 class Tickit::Widget::HSplit
    extends Tickit::Widget::LinearSplit;
 
@@ -99,15 +99,15 @@ Constructs a new C<Tickit::Widget::HSplit> object.
 
 =cut
 
-BUILD
+ADJUSTPARAMS
 {
-   my %args = @_;
+   my ( $params ) = @_;
 
    croak "The 'top_child' constructor argument to ${\ref $self} is no longer recognised; use ->set_top_child instead"
-      if $args{top_child};
+      if delete $params->{top_child};
 
    croak "The 'bottom_child' constructor argument to ${\ref $self} is no longer recognised; use ->set_bottom_child instead"
-      if $args{bottom_child};
+      if delete $params->{bottom_child};
 }
 
 method lines
