@@ -3,15 +3,14 @@
 #
 #  (C) Paul Evans, 2009-2020 -- leonerd@leonerd.org.uk
 
-package Tickit::Widget::VBox;
+use Object::Pad 0.09;
+
+package Tickit::Widget::VBox 0.49;
+class Tickit::Widget::VBox
+   extends Tickit::Widget::LinearBox;
 
-use strict;
-use warnings;
-use base qw( Tickit::Widget::LinearBox );
 use Tickit::Style;
 
-our $VERSION = '0.48';
-
 use List::Util qw( sum max );
 
 =head1 NAME
@@ -73,37 +72,32 @@ style_reshape_keys qw( spacing );
 
 use constant WIDGET_PEN_FROM_STYLE => 1;
 
-sub lines
+method lines
 {
-   my $self = shift;
    my $spacing = $self->get_style_values( "spacing" );
    return ( sum( map { $_->requested_lines } $self->children ) || 1 ) +
           $spacing * ( $self->children - 1 );
 }
 
-sub cols
+method cols
 {
-   my $self = shift;
    return max( 1, map { $_->requested_cols } $self->children );
 }
 
-sub get_total_quota
+method get_total_quota
 {
-   my $self = shift;
    my ( $window ) = @_;
    return $window->lines;
 }
 
-sub get_child_base
+method get_child_base
 {
-   my $self = shift;
    my ( $child ) = @_;
    return $child->requested_lines;
 }
 
-sub set_child_window
+method set_child_window
 {
-   my $self = shift;
    my ( $child, $top, $lines, $window ) = @_;
 
    if( $window and $lines ) {
